Buffer

Enum Buffer 

#[repr(u32)]
pub enum Buffer { Default = 2_147_483_647, Main = 0, Crash = 4, Stats = 5, Events = 2, Security = 6, System = 3, Kernel = 7, Radio = 1, }
Variants



Default = 2_147_483_647

Let the logging function choose the best log target.



Main = 0

The main log buffer.

This is the only log buffer available to apps.



Crash = 4

The crash log buffer.



Stats = 5

The statistics log buffer.



Events = 2

The event log buffer.



Security = 6

The security log buffer.



System = 3

The system log buffer.



Kernel = 7

The kernel log buffer.



Radio = 1

The radio log buffer.